From 0676d720432e3eeb6ccfede4f0b36488f9664fcc Mon Sep 17 00:00:00 2001
From: Andrew James <andrew.james@hp.com>
Date: Tue, 7 Oct 2014 15:01:44 -0600
Subject: [PATCH] Don't override user-specified --extrapackages

---
 cowbuilder.c     |  3 +++
 debian/changelog |  6 ++++++
 parameter.c      | 11 ++++++++++-
 parameter.h      |  1 +
 4 files changed, 20 insertions(+), 1 deletion(-)

diff --git a/cowbuilder.c b/cowbuilder.c
index 2fae643..03fe8ab 100755
--- a/cowbuilder.c
+++ b/cowbuilder.c
@@ -380,8 +380,11 @@ int cpbuilder_create(const struct pbuilderconfig* pc)
   PBUILDER_ADD_PARAM("--distribution");
   PBUILDER_ADD_PARAM(pc->distribution);
   PBUILDER_ADD_PARAM("--no-targz");
+
   PBUILDER_ADD_PARAM("--extrapackages");
+  PBUILDER_ADD_PARAM(pc->extrapackages);
   PBUILDER_ADD_PARAM("cowdancer");
+
   PBUILDER_ADD_PARAM(NULL);
   ret=forkexecvp(pbuildercommandline);
 
diff --git a/debian/changelog b/debian/changelog
index cd456d4..5919f32 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,9 @@
+cowdancer (0.73.1) UNRELEASED; urgency=low
+
+  * Don't override user-specified --extrapackages when adding cowdancer
+
+ -- Andrew James <andrew.james@hp.com>  Tue, 07 Oct 2014 15:22:47 -0600
+
 cowdancer (0.73) unstable; urgency=low
 
   * debbuildopts quoting is wrong from ~/.pbuilderrc (closes: #704247)
diff --git a/parameter.c b/parameter.c
index 8c015a6..f4fe7d3 100644
--- a/parameter.c
+++ b/parameter.c
@@ -158,6 +158,10 @@ int load_config_file(const char* config, pbuilderconfig* pc)
 	    {
 	      pc->components=strdup_strip_quote(delim);
 	    }
+	  else if (!strcmp(buf, "EXTRAPACKAGES"))
+	    {
+	      pc->extrapackages=strdup_strip_quote(delim);
+	    }
 	  else if (!strcmp(buf, "OTHERMIRROR"))
 	    {
 	      pc->othermirror=strdup_strip_quote(delim);
@@ -284,6 +288,7 @@ int parse_parameter(int ac, char** av,
     {"buildresult", required_argument, 0, 0},
     {"distribution", required_argument, 0, 0},
     {"components", required_argument, 0, 0},
+    {"extrapackages", required_argument, 0, 0},
     {"othermirror", required_argument, 0, 0},
     {"smp", required_argument, 0, 0},
     {"debbuildopts", required_argument, 0, 0},
@@ -302,7 +307,6 @@ int parse_parameter(int ac, char** av,
 
     /* verbatim options with argument, synced as of pbuilder 0.153 */
     {"aptcache", required_argument, 0, 'M'},
-    {"extrapackages", required_argument, 0, 'M'},
     {"hookdir", required_argument, 0, 'M'},
     {"debemail", required_argument, 0, 'M'},
     {"logfile", required_argument, 0, 'M'},
@@ -484,6 +488,11 @@ int parse_parameter(int ac, char** av,
 	      /* pass it for cowbuilder */
 	      PASS_TO_PBUILDER_WITH_PARAM
 	    }
+	  else if (!strcmp(long_options[index_point].name,"extrapackages"))
+	    {
+	      /* cowdancer will be added to this in cpbuilder_create */
+	      pc.extrapackages=strdup(optarg);
+	    }
 	  else if (!strcmp(long_options[index_point].name,"othermirror"))
 	    {
 	      /* this is for qemubuilder */
diff --git a/parameter.h b/parameter.h
index 9ef23a7..ad2f204 100644
--- a/parameter.h
+++ b/parameter.h
@@ -37,6 +37,7 @@ typedef struct pbuilderconfig
   char* mirror;
   char* distribution;
   char* components;
+  char* extrapackages;
   char* othermirror;
   char* debbuildopts;
   int binary_arch;
-- 
2.1.1

